@@ -393,8 +393,8 @@ class AnalyticsHubServiceAsyncClient:
         Args:
             request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListOrgDataExchangesRequest, dict]]):
                 The request object. Message for requesting the list of
-                data exchanges from projects in an organization and
-                location.
+                data exchanges from projects in an
+                organization and location.
             organization (:class:`str`):
                 Required. The organization resource path of the projects
                 containing DataExchanges. e.g.
@@ -621,8 +621,7 @@ class AnalyticsHubServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.CreateDataExchangeRequest, dict]]):
-                The request object. Message for creating a data
-                exchange.
+                The request object. Message for creating a data exchange.
             parent (:class:`str`):
                 Required. The parent resource path of the data exchange.
                 e.g. ``projects/myproject/locations/US``.
@@ -739,8 +738,7 @@ class AnalyticsHubServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.UpdateDataExchangeRequest, dict]]):
-                The request object. Message for updating a data
-                exchange.
+                The request object. Message for updating a data exchange.
             data_exchange (:class:`google.cloud.bigquery_data_exchange_v1beta1.types.DataExchange`):
                 Required. The data exchange to
                 update.
@@ -854,8 +852,7 @@ class AnalyticsHubServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.DeleteDataExchangeRequest, dict]]):
-                The request object. Message for deleting a data
-                exchange.
+                The request object. Message for deleting a data exchange.
             name (:class:`str`):
                 Required. The full name of the data exchange resource
                 that you want to delete. For example,
@@ -1506,8 +1503,7 @@ class AnalyticsHubServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.SubscribeListingRequest, dict]]):
-                The request object. Message for subscribing to a
-                listing.
+                The request object. Message for subscribing to a listing.
             name (:class:`str`):
                 Required. Resource name of the listing that you want to
                 subscribe to. e.g.
@@ -1609,8 +1605,7 @@ class AnalyticsHubServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]]):
-                The request object. Request message for `GetIamPolicy`
-                method.
+                The request object. Request message for ``GetIamPolicy`` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1752,8 +1747,7 @@ class AnalyticsHubServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]]):
-                The request object. Request message for `SetIamPolicy`
-                method.
+                The request object. Request message for ``SetIamPolicy`` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1896,8 +1890,7 @@ class AnalyticsHubServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]]):
-                The request object. Request message for
-                `TestIamPermissions` method.
+                The request object. Request message for ``TestIamPermissions`` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
