@@ -654,8 +654,8 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListOrgDataExchangesRequest, dict]):
                 The request object. Message for requesting the list of
-                data exchanges from projects in an organization and
-                location.
+                data exchanges from projects in an
+                organization and location.
             organization (str):
                 Required. The organization resource path of the projects
                 containing DataExchanges. e.g.
@@ -882,8 +882,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.CreateDataExchangeRequest, dict]):
-                The request object. Message for creating a data
-                exchange.
+                The request object. Message for creating a data exchange.
             parent (str):
                 Required. The parent resource path of the data exchange.
                 e.g. ``projects/myproject/locations/US``.
@@ -1000,8 +999,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.UpdateDataExchangeRequest, dict]):
-                The request object. Message for updating a data
-                exchange.
+                The request object. Message for updating a data exchange.
             data_exchange (google.cloud.bigquery_data_exchange_v1beta1.types.DataExchange):
                 Required. The data exchange to
                 update.
@@ -1115,8 +1113,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.DeleteDataExchangeRequest, dict]):
-                The request object. Message for deleting a data
-                exchange.
+                The request object. Message for deleting a data exchange.
             name (str):
                 Required. The full name of the data exchange resource
                 that you want to delete. For example,
@@ -1767,8 +1764,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.SubscribeListingRequest, dict]):
-                The request object. Message for subscribing to a
-                listing.
+                The request object. Message for subscribing to a listing.
             name (str):
                 Required. Resource name of the listing that you want to
                 subscribe to. e.g.
@@ -1870,8 +1866,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
-                The request object. Request message for `GetIamPolicy`
-                method.
+                The request object. Request message for ``GetIamPolicy`` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -2012,8 +2007,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
-                The request object. Request message for `SetIamPolicy`
-                method.
+                The request object. Request message for ``SetIamPolicy`` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -2155,8 +2149,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
-                The request object. Request message for
-                `TestIamPermissions` method.
+                The request object. Request message for ``TestIamPermissions`` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
